@@ -27,8 +27,8 @@
  */
 #define NBSSmessage     0x00   /* session message */
 #define NBSSrequest     0x81   /* session request */
-#define NBSSpositive    0x82   /* positiv session response */
-#define NBSSnegative    0x83   /* negativ session response */
+#define NBSSpositive    0x82   /* positive session response */
+#define NBSSnegative    0x83   /* negative session response */
 #define NBSSretarget    0x84   /* retarget session response */
 #define NBSSkeepalive   0x85   /* keepalive */
 
@@ -329,7 +329,7 @@ enum csc_policy {
 #define FLAGS2_UNICODE_STRINGS         0x8000
 
 /* FileAttributes (search attributes) field */
-#define FILE_ATTRIBUTES_INVALID 	0x0000L
+#define FILE_ATTRIBUTE_INVALID 		0x0000L
 #define FILE_ATTRIBUTE_READONLY		0x0001L
 #define FILE_ATTRIBUTE_HIDDEN		0x0002L
 #define FILE_ATTRIBUTE_SYSTEM		0x0004L
@@ -400,7 +400,7 @@ enum csc_policy {
 #define FILE_CASE_PRESERVED_NAMES       0x00000002
 #define FILE_UNICODE_ON_DISK            0x00000004
 /* According to cifs9f, this is 4, not 8 */
-/* Acconding to testing, this actually sets the security attribute! */
+/* According to testing, this actually sets the security attribute! */
 #define FILE_PERSISTENT_ACLS            0x00000008
 #define FILE_FILE_COMPRESSION           0x00000010
 #define FILE_VOLUME_QUOTAS              0x00000020
@@ -607,6 +607,7 @@ enum csc_policy {
  * A few values from [MS-FSCC] 2.1.2.1 Reparse Tags
  */
 
+#define IO_REPARSE_TAG_RESERVED_ZERO 0x00000000
 #define IO_REPARSE_TAG_SYMLINK	     0xA000000C
 #define IO_REPARSE_TAG_MOUNT_POINT   0xA0000003
 #define IO_REPARSE_TAG_HSM           0xC0000004
@@ -614,6 +615,16 @@ enum csc_policy {
 #define IO_REPARSE_TAG_DFS	     0x8000000A
 #define IO_REPARSE_TAG_NFS	     0x80000014
 
+/*
+ * Sub-types for IO_REPARSE_TAG_NFS from [MS-FSCC] 2.1.2.6 Network
+ * File System (NFS) Reparse Data Buffer
+ */
+#define NFS_SPECFILE_LNK	     0x00000000014B4E4C
+#define NFS_SPECFILE_CHR	     0x0000000000524843
+#define NFS_SPECFILE_BLK	     0x00000000004B4C42
+#define NFS_SPECFILE_FIFO	     0x000000004F464946
+#define NFS_SPECFILE_SOCK	     0x000000004B434F53
+
 /*
  * Flag from [MS-FSCC] 2.1.2.4 Symbolic Link Reparse Data Buffer
  */
